summaryrefslogtreecommitdiffstats
path: root/templates/annotated/minimal.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:05:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:05:23 -0600
commit6677c2f8c66333c3951e8830f8760065c7a29074 (patch)
treee45d51b044ce8575210fca1584852fbbe4742316 /templates/annotated/minimal.py
parent1d7616d07ef6f1e6c8131a861ddff208557825e3 (diff)
downloadpytde-6677c2f8c66333c3951e8830f8760065c7a29074.tar.gz
pytde-6677c2f8c66333c3951e8830f8760065c7a29074.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'templates/annotated/minimal.py')
-rw-r--r--templates/annotated/minimal.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/templates/annotated/minimal.py b/templates/annotated/minimal.py
index e021851..817d140 100644
--- a/templates/annotated/minimal.py
+++ b/templates/annotated/minimal.py
@@ -34,7 +34,7 @@ copyright holder.
import sys
-from tdecore import KApplication
+from tdecore import TDEApplication
from tdeui import KMainWindow
@@ -56,11 +56,11 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
# instantiate KApplication - no other TQObject
# or TQWidget based classes can be instantiated
# until there is a KApplication instance
appName = "template"
-app = KApplication (sys.argv, appName)
+app = TDEApplication (sys.argv, appName)
# instantiate the subclass of KMainWindow
mainWindow = MainWin (None, "main window")
@@ -68,7 +68,7 @@ mainWindow = MainWin (None, "main window")
# create the display
mainWindow.show()
# run KApplication's event loop until the
# program exits
app.exec_loop()
@@ -56,11 +56,11 @@ class MainWin (KMainWindow):
#-------------------- main ------------------------------------------------
-# instantiate KApplication - no other TQObject
+# instantiate TDEApplication - no other TQObject
# or TQWidget based classes can be instantiated
@@ -56,11 +56,11 @@ class MainWin (KMainWindow):
# or TQWidget based classes can be instantiated
-# until there is a KApplication instance
+# until there is a TDEApplication instance
appName = "template"
@@ -68,7 +68,7 @@ mainWindow = MainWin (None, "main window")
# create the display
mainWindow.show()
-# run KApplication's event loop until the
+# run TDEApplication's event loop until the
# program exits
app.exec_loop()